@@ -23,16 +23,34 @@ async_label: {
 }
 
 await_await: {
+    options = {
+        awaits: true,
+        side_effects: true,
+    }
     input: {
         (async function() {
-            console.log("PASS");
-            await await 42;
+            await await {
+                then(resolve) {
+                    resolve({
+                        then() {
+                            console.log("PASS");
+                        },
+                    });
+                },
+            };
         })();
     }
     expect: {
         (async function() {
-            console.log("PASS");
-            await await 42;
+            await {
+                then(resolve) {
+                    resolve({
+                        then() {
+                            console.log("PASS");
+                        },
+                    });
+                },
+            };
         })();
     }
     expect_stdout: "PASS"
@@ -546,7 +564,7 @@ drop_return: {
     input: {
         (async function(a) {
             while (!console);
-            return console.log(a);
+            return !console.log(a);
         })(42);
     }
     expect: {
@@ -596,14 +614,14 @@ functions: {
             async function b() {
                 return !!b;
             }
-            var c = async function(c) {
+            async function c(c) {
                 return c;
-            };
+            }
             if (await c(await b(await a()))) {
-                async function d() {}
-                async function e() {
-                    return typeof e;
-                }
+                var d = async function() {};
+                var e = async function y() {
+                    return typeof y;
+                };
                 var f = async function(f) {
                     return f;
                 };
@@ -654,9 +672,9 @@ functions_use_strict: {
             async function b() {
                 return !!b;
             }
-            var c = async function(c) {
+            async function c(c) {
                 return c;
-            };
+            }
             if (await c(await b(await a()))) {
                 var d = async function() {};
                 var e = async function y() {
@@ -673,6 +691,54 @@ functions_use_strict: {
     node_version: ">=8"
 }
 
+functions_anonymous: {
+    options = {
+        functions: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var await = async function() {
+            console.log("PASS");
+        };
+        await(await);
+    }
+    expect: {
+        async function await() {
+            console.log("PASS");
+        }
+        await();
+    }
+    expect_stdout: "PASS"
+    node_version: ">=8"
+}
+
+functions_inner_var: {
+    options = {
+        functions: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var await = function a() {
+            var a;
+            console.log(a, a);
+        };
+        await(await);
+    }
+    expect: {
+        function await() {
+            var a;
+            console.log(a, a);
+        }
+        await();
+    }
+    expect_stdout: "undefined undefined"
+    node_version: ">=8"
+}
+
 issue_4335_1: {
     options = {
         inline: true,
@@ -1246,3 +1312,222 @@ issue_4618: {
     expect_stdout: "function"
     node_version: ">=8"
 }
+
+issue_4717: {
+    options = {
+        inline: true,
+        reduce_vars: true,
+        sequences: true,
+        side_effects: true,
+        unused: true,
+    }
+    input: {
+        (function() {
+            async function f() {
+                var a = function() {
+                    await;
+                }();
+                return "FAIL";
+            }
+            return f();
+        })().then(console.log).catch(function() {
+            console.log("PASS");
+        });
+    }
+    expect: {
+        (async function() {
+            return function() {
+                await;
+            }(), "FAIL";
+        })().then(console.log).catch(function() {
+            console.log("PASS");
+        });
+    }
+    expect_stdout: "PASS"
+    node_version: ">=8"
+}
+
+issue_4738_1: {
+    options = {
+        awaits: true,
+        side_effects: true,
+    }
+    input: {
+        (async function() {
+            await {
+                then() {
+                    console.log("PASS");
+                },
+            };
+        })();
+    }
+    expect: {
+        (async function() {
+            await {
+                then() {
+                    console.log("PASS");
+                },
+            };
+        })();
+    }
+    expect_stdout: "PASS"
+    node_version: ">=8"
+}
+
+issue_4738_2: {
+    options = {
+        awaits: true,
+        side_effects: true,
+    }
+    input: {
+        (async function() {
+            await {
+                get then() {
+                    console.log("PASS");
+                },
+            };
+        })();
+    }
+    expect: {
+        (async function() {
+            await {
+                get then() {
+                    console.log("PASS");
+                },
+            };
+        })();
+    }
+    expect_stdout: "PASS"
+    node_version: ">=8"
+}
+
+issue_4738_3: {
+    options = {
+        awaits: true,
+        side_effects: true,
+    }
+    input: {
+        (async function() {
+            await {
+                then: function() {
+                    console.log("PASS");
+                },
+            };
+        })();
+    }
+    expect: {
+        (async function() {
+            await {
+                then: function() {
+                    console.log("PASS");
+                },
+            };
+        })();
+    }
+    expect_stdout: "PASS"
+    node_version: ">=8"
+}
+
+issue_4747: {
+    options = {
+        collapse_vars: true,
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        console.log(function(a) {
+            async function f() {
+                a = "PASS";
+                null.p += "PASS";
+            }
+            f();
+            return a;
+        }("FAIL"));
+    }
+    expect: {
+        console.log(function(a) {
+            (async function() {
+                a = "PASS";
+                null.p += "PASS";
+            })();
+            return a;
+        }("FAIL"));
+    }
+    expect_stdout: "PASS"
+    node_version: ">=8"
+}
+
+issue_4764_1: {
+    options = {
+        side_effects: true,
+    }
+    input: {
+        (async function() {
+            return {
+                then() {
+                    console.log("PASS");
+                },
+            };
+        })();
+    }
+    expect: {
+        (async function() {
+            return {
+                then() {
+                    console.log("PASS");
+                },
+            };
+        })();
+    }
+    expect_stdout: "PASS"
+    node_version: ">=8"
+}
+
+issue_4764_2: {
+    options = {
+        arrows: true,
+        side_effects: true,
+    }
+    input: {
+        (async () => ({
+            get then() {
+                console.log("PASS");
+            },
+        }))();
+    }
+    expect: {
+        (async () => ({
+            get then() {
+                console.log("PASS");
+            },
+        }))();
+    }
+    expect_stdout: "PASS"
+    node_version: ">=8"
+}
+
+issue_4764_3: {
+    options = {
+        side_effects: true,
+    }
+    input: {
+        (async function(o) {
+            return o;
+        })({
+            then() {
+                console.log("PASS");
+            },
+        });
+    }
+    expect: {
+        (async function(o) {
+            return o;
+        })({
+            then() {
+                console.log("PASS");
+            },
+        });
+    }
+    expect_stdout: "PASS"
+    node_version: ">=8"
+}
