@@ -473,7 +473,7 @@ inline_side_effects_2: {
     }
     expect: {
         var a = 42;
-        [ 0[0] = --a ] = [ console ];
+        [ [].e = --a ] = [ console ];
         console.log(a);
     }
     expect_stdout: "42"
@@ -1477,7 +1477,7 @@ issue_4502_4: {
         (function(a, b = console.log("FAIL")) {})(..."" + console.log(42));
     }
     expect: {
-        [ , 0[0] = console.log("FAIL") ] = [ ..."" + console.log(42) ];
+        [ , [].e = console.log("FAIL") ] = [ ..."" + console.log(42) ];
     }
     expect_stdout: "42"
     node_version: ">=6"
@@ -1661,3 +1661,23 @@ issue_4588_2_evaluate: {
     expect_stdout: "1"
     node_version: ">=6"
 }
+
+issue_4817: {
+    options = {
+        ie8: true,
+        inline: true,
+        unused: true,
+    }
+    input: {
+        (function f(a = console.log(typeof f)) {
+            return 42;
+        })();
+    }
+    expect: {
+        (function f(a = console.log(typeof f)) {
+            return 42;
+        })();
+    }
+    expect_stdout: "function"
+    node_version: ">=6"
+}
