@@ -3251,3 +3251,140 @@ issue_4558_2: {
     }
     expect_stdout: "PASS"
 }
+
+issue_4662: {
+    options = {
+        evaluate: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var a = 0;
+        function f(b, c) {
+            console.log(b, c);
+        }
+        f(++a, a = a, a);
+    }
+    expect: {
+        var a = 0;
+        (function(b, c) {
+            console.log(b, c);
+        })(++a, a = 1);
+    }
+    expect_stdout: "1 1"
+}
+
+issue_4806_1: {
+    options = {
+        evaluate: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        O = {
+            f: function() {
+                console.log(this === O ? "FAIL" : "PASS");
+            },
+        };
+        var a;
+        (a = 42, O.f)();
+        a;
+    }
+    expect: {
+        O = {
+            f: function() {
+                console.log(this === O ? "FAIL" : "PASS");
+            },
+        };
+        (0, O.f)();
+        42;
+    }
+    expect_stdout: "PASS"
+}
+
+issue_4806_2: {
+    options = {
+        sequences: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        O = {
+            f: function() {
+                console.log(this === O ? "FAIL" : "PASS");
+            },
+        };
+        var a;
+        (a = 42, O.f)();
+        a;
+    }
+    expect: {
+        O = {
+            f: function() {
+                console.log(this === O ? "FAIL" : "PASS");
+            },
+        },
+        (0, O.f)();
+    }
+    expect_stdout: "PASS"
+}
+
+issue_4806_3: {
+    options = {
+        side_effects: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        O = {
+            f: function() {
+                console.log(this === O ? "FAIL" : "PASS");
+            },
+        };
+        var a;
+        (a = 42, O.f)();
+        a;
+    }
+    expect: {
+        O = {
+            f: function() {
+                console.log(this === O ? "FAIL" : "PASS");
+            },
+        };
+        (0, O.f)();
+    }
+    expect_stdout: "PASS"
+}
+
+issue_4834: {
+    options = {
+        inline: true,
+        keep_fargs: false,
+        pure_getters: "strict",
+        reduce_vars: true,
+        side_effects: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        try {
+            new function(a, b) {
+                b;
+                b.p;
+            }(42);
+        } catch (e) {
+            console.log("PASS");
+        }
+    }
+    expect: {
+        try {
+            void b.p;
+        } catch (e) {
+            console.log("PASS");
+        }
+        var b;
+    }
+    expect_stdout: "PASS"
+}
