@@ -152,7 +152,7 @@ issue_4487: {
     }
     expect: {
         function a() {
-            var a = console.log(typeof a);
+            var f = console.log(typeof f);
         }
         a();
     }
@@ -207,3 +207,61 @@ issue_4517: {
     }
     expect_stdout: "2boolean"
 }
+
+issue_4736: {
+    options = {
+        collapse_vars: true,
+        evaluate: true,
+        hoist_vars: true,
+        merge_vars: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var a;
+        function f() {
+            (function g() {
+                var b = (a = 0, 1 << 30);
+                var c = (a = 0, console.log(b));
+                var d = c;
+            })(f);
+        }
+        f();
+    }
+    expect: {
+        (function() {
+            (function() {
+                0,
+                console.log(1073741824);
+            })();
+        })();
+    }
+    expect_stdout: "1073741824"
+}
+
+issue_4839: {
+    options = {
+        evaluate: true,
+        hoist_vars: true,
+        keep_fargs: false,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var o = function(a, b) {
+            return b && b;
+        }("foo");
+        for (var k in o)
+            throw "FAIL";
+        console.log("PASS");
+    }
+    expect: {
+        var k, o = void 0;
+        for (k in o)
+            throw "FAIL";
+        console.log("PASS");
+    }
+    expect_stdout: "PASS"
+}
