@@ -359,7 +359,7 @@ reduce_block_2_toplevel: {
     node_version: ">=4"
 }
 
-reduce_vars: {
+reduce_vars_1: {
     options = {
         evaluate: true,
         reduce_vars: true,
@@ -381,6 +381,86 @@ reduce_vars: {
     node_version: ">=4"
 }
 
+reduce_vars_2: {
+    options = {
+        reduce_funcs: true,
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        (function() {
+            function f() {
+                console.log(typeof a);
+            }
+            for (let a in [ 42 ])
+                f();
+        })();
+    }
+    expect: {
+        "use strict";
+        (function() {
+            function f() {
+                console.log(typeof a);
+            }
+            for (let a in [ 42 ])
+                f();
+        })();
+    }
+    expect_stdout: "undefined"
+    node_version: ">=4"
+}
+
+reduce_vars_3: {
+    options = {
+        reduce_funcs: true,
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        (function(a) {
+            let i = 1;
+            function f() {
+                i = 0;
+            }
+            for (let i = 0, x = 0; i < a.length; i++, x++) {
+                if (x != i) {
+                    console.log("FAIL");
+                    break;
+                }
+                f();
+                console.log(a[i]);
+            }
+            console.log(i);
+        })([ 4, 2 ]);
+    }
+    expect: {
+        "use strict";
+        (function(a) {
+            let i = 1;
+            function f() {
+                i = 0;
+            }
+            for (let i = 0, x = 0; i < a.length; i++, x++) {
+                if (x != i) {
+                    console.log("FAIL");
+                    break;
+                }
+                f();
+                console.log(a[i]);
+            }
+            console.log(i);
+        })([ 4, 2 ]);
+    }
+    expect_stdout: [
+        "4",
+        "2",
+        "0",
+    ]
+    node_version: ">=4"
+}
+
 hoist_props: {
     options = {
         hoist_props: true,
@@ -610,6 +690,28 @@ drop_unused: {
     node_version: ">=4"
 }
 
+default_init: {
+    options = {
+        evaluate: true,
+        reduce_vars: true,
+        sequences: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        "use strict";
+        let a;
+        a = "PASS";
+        console.log(a);
+    }
+    expect: {
+        "use strict";
+        console.log("PASS");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
+
 issue_4191: {
     options = {
         functions: true,
@@ -1319,7 +1421,6 @@ issue_4531_2: {
         toplevel: true,
     }
     input: {
-        "use strict";
         var a = console;
         console.log(typeof a, function a() {
             let { [console]: a } = 0 && a;
@@ -1328,7 +1429,6 @@ issue_4531_2: {
         }());
     }
     expect: {
-        "use strict";
         var o = console;
         console.log(typeof o, function o() {
             let { [console]: o } = 0;
@@ -1339,3 +1439,110 @@ issue_4531_2: {
     expect_stdout: "object undefined"
     node_version: ">=6"
 }
+
+issue_4689: {
+    options = {
+        sequences: true,
+    }
+    input: {
+        "use strict";
+        var a = "PASS";
+        console.log(a);
+        for (let a in 42);
+    }
+    expect: {
+        "use strict";
+        var a = "PASS";
+        console.log(a);
+        for (let a in 42);
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
+
+issue_4691: {
+    options = {
+        if_return: true,
+        toplevel: true,
+    }
+    input: {
+        "use strict";
+        function A() {}
+        A.prototype.f = function() {
+            if (!this)
+                return;
+            let a = "PA";
+            function g(b) {
+                h(a + b);
+            }
+            [ "SS" ].forEach(function(c) {
+                g(c);
+            });
+        };
+        function h(d) {
+            console.log(d);
+        }
+        new A().f();
+    }
+    expect: {
+        "use strict";
+        function A() {}
+        A.prototype.f = function() {
+            if (this) {
+                let a = "PA";
+                [ "SS" ].forEach(function(c) {
+                    g(c);
+                });
+                function g(b) {
+                    h(a + b);
+                }
+            }
+        };
+        function h(d) {
+            console.log(d);
+        }
+        new A().f();
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
+
+issue_4848: {
+    options = {
+        if_return: true,
+    }
+    input: {
+        "use strict";
+        function f(a) {
+            a(function() {
+                console.log(b);
+            });
+            if (!console)
+                return;
+            let b = "PASS";
+        }
+        var g;
+        f(function(h) {
+            g = h;
+        });
+        g();
+    }
+    expect: {
+        "use strict";
+        function f(a) {
+            a(function() {
+                console.log(b);
+            });
+            if (!console)
+                return;
+            let b = "PASS";
+        }
+        var g;
+        f(function(h) {
+            g = h;
+        });
+        g();
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
