@@ -2620,9 +2620,9 @@ issue_4126_1: {
             try {
                 console.log("PASS");
             } catch (e) {
-                var b = a;
+                var c = a;
             } finally {
-                var c = b;
+                var c = c;
             }
             console.log(c);
         }
@@ -3212,3 +3212,92 @@ issue_4628: {
     }
     expect_stdout: "undefined"
 }
+
+issue_4653: {
+    options = {
+        evaluate: true,
+        merge_vars: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var a = 1, b;
+        function f(c, d) {
+            c || console.log(d);
+        }
+        f(a++ + (b = b), b |= console.log(a));
+    }
+    expect: {
+        var b = 1;
+        (function(c, d) {
+            c || console.log(d);
+        })(+b + (b = void 0), b |= console.log(2));
+    }
+    expect_stdout: [
+        "2",
+        "0",
+    ]
+}
+
+issue_4759: {
+    options = {
+        merge_vars: true,
+        toplevel: true,
+    }
+    input: {
+        var i = 2, a = 1, b, c, d;
+        while (i--) {
+            try {
+                if (1 != b) {
+                    d = [];
+                    null.p;
+                    c = d;
+                } else {
+                    b = 0;
+                    a = c;
+                }
+            } catch (e) {}
+            b = a;
+        }
+        console.log(a);
+    }
+    expect: {
+        var i = 2, a = 1, b, c, d;
+        while (i--) {
+            try {
+                if (1 != b) {
+                    d = [];
+                    null.p;
+                    c = d;
+                } else {
+                    b = 0;
+                    a = c;
+                }
+            } catch (e) {}
+            b = a;
+        }
+        console.log(a);
+    }
+    expect_stdout: "undefined"
+}
+
+issue_4761: {
+    options = {
+        merge_vars: true,
+        toplevel: true,
+    }
+    input: {
+        var a = "FAIL", b;
+        try {
+            !a && --a && (b = 0)[console] || console.log(b);
+        } catch (e) {}
+    }
+    expect: {
+        var a = "FAIL", b;
+        try {
+            !a && --a && (b = 0)[console] || console.log(b);
+        } catch (e) {}
+    }
+    expect_stdout: "undefined"
+}
