@@ -673,27 +673,21 @@ issue_4575: {
         unused: true,
     }
     input: {
-        A = "PASS";
-        (function() {
-            var a = 0, b = a;
-            var c = function a(...b) {
-                A;
-                var d = A;
-                console.log(d, b.length);
+        (function(a) {
+            var b = a;
+            var c = function a(...d) {
+                console.log(d.length);
             }();
         })();
     }
     expect: {
-        A = "PASS";
-        (function() {
-            (function(b) {
-                A;
-                var d = A;
-                console.log(d, b.length);
-            })([]);
+        (function(a) {
+            (function a(...d) {
+                console.log(d.length);
+            })();
         })();
     }
-    expect_stdout: "PASS 0"
+    expect_stdout: "0"
     node_version: ">=6"
 }
 
@@ -763,3 +757,30 @@ issue_4644_2: {
     expect_stdout: "PASS 0 undefined"
     node_version: ">=6"
 }
+
+issue_4666: {
+    options = {
+        evaluate: true,
+        reduce_vars: true,
+        rests: true,
+        toplevel: true,
+        unsafe: true,
+        unused: true,
+    }
+    input: {
+        var a = 0, b = 0;
+        var o = ((...c) => a++ + c)(b);
+        for (var k in o)
+            b++;
+        console.log(a, b);
+    }
+    expect: {
+        var a = 0, b = 0;
+        var o = (c => +a + c)([ b ]);
+        for(var k in o)
+            b++;
+        console.log(1, b);
+    }
+    expect_stdout: "1 2"
+    node_version: ">=6"
+}
