@@ -85,7 +85,7 @@ collapse_vars_4: {
     node_version: ">=6"
 }
 
-conditionals_farg: {
+conditionals_farg_1: {
     options = {
         conditionals: true,
     }
@@ -107,6 +107,28 @@ conditionals_farg: {
     node_version: ">=6"
 }
 
+conditionals_farg_2: {
+    options = {
+        conditionals: true,
+        pure_getters: "strict",
+        reduce_vars: true,
+    }
+    input: {
+        var log = console.log;
+        (function(a) {
+            return a.length ? log(...a) : log("FAIL");
+        })([ "PASS" ]);
+    }
+    expect: {
+        var log = console.log;
+        (function(a) {
+            return a.length ? log(...a) : log("FAIL");
+        })([ "PASS" ]);
+    }
+    expect_stdout: "PASS"
+    node_version: ">=6"
+}
+
 dont_inline: {
     options = {
         inline: true,
@@ -272,6 +294,31 @@ reduce_vars_2: {
     node_version: ">=6"
 }
 
+reduce_vars_3: {
+    options = {
+        reduce_funcs: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        function f() {}
+        function g() {
+            return (a => a)(...[ f ]);
+        }
+        console.log(g() === g() ? "PASS" : "FAIL");
+    }
+    expect: {
+        function f() {}
+        function g() {
+            return (a => a)(...[ f ]);
+        }
+        console.log(g() === g() ? "PASS" : "FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=6"
+}
+
 convert_setter: {
     options = {
         objects: true,
@@ -667,6 +714,57 @@ unused_var_side_effects: {
     node_version: ">=8"
 }
 
+unsafe_join_1: {
+    options = {
+        unsafe: true,
+    }
+    input: {
+        console.log([ ..."foo" ].join());
+    }
+    expect: {
+        console.log([ ..."foo" ].join());
+    }
+    expect_stdout: "f,o,o"
+    node_version: ">=6"
+}
+
+unsafe_join_2: {
+    options = {
+        evaluate: true,
+        unsafe: true,
+    }
+    input: {
+        console.log([ "foo", ..."bar" ].join(""));
+    }
+    expect: {
+        console.log([ "foo", ..."bar" ].join(""));
+    }
+    expect_stdout: "foobar"
+    node_version: ">=6"
+}
+
+unsafe_join_3: {
+    options = {
+        unsafe: true,
+    }
+    input: {
+        try {
+            [].join(...console);
+        } catch (e) {
+            console.log("PASS");
+        }
+    }
+    expect: {
+        try {
+            [].join(...console);
+        } catch (e) {
+            console.log("PASS");
+        }
+    }
+    expect_stdout: "PASS"
+    node_version: ">=6"
+}
+
 issue_4329: {
     options = {
         objects: true,
@@ -947,3 +1045,26 @@ issue_4614: {
     expect_stdout: true
     node_version: ">=6"
 }
+
+issue_4849: {
+    options = {
+        reduce_vars: true,
+        unused: true,
+    }
+    input: {
+        while (function() {
+            while (!console);
+        }(new function(a) {
+            console.log(typeof { ...a });
+        }(function() {})));
+    }
+    expect: {
+        while (function() {
+            while (!console);
+        }(function(a) {
+            console.log(typeof { ...function() {} });
+        }()));
+    }
+    expect_stdout: "object"
+    node_version: ">=8"
+}
