@@ -53,7 +53,7 @@ tagged_chain: {
     node_version: ">=4"
 }
 
-tag_parenthesis_arrow: {
+tag_parentheses_arrow: {
     input: {
         console.log((s => s.raw[0])`\tPASS`.slice(2));
     }
@@ -62,7 +62,7 @@ tag_parenthesis_arrow: {
     node_version: ">=4"
 }
 
-tag_parenthesis_new: {
+tag_parentheses_new: {
     input: {
         (new function() {
             return console.log;
@@ -73,6 +73,20 @@ tag_parenthesis_new: {
     node_version: ">=4"
 }
 
+tag_parentheses_sequence: {
+    input: {
+        var o = {
+            f() {
+                console.log(this === o ? "FAIL" : "PASS");
+            },
+        };
+        (42, o.f)``;
+    }
+    expect_exact: 'var o={f(){console.log(this===o?"FAIL":"PASS")}};(42,o.f)``;'
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
+
 malformed_escape: {
     input: {
         (function(s) {
@@ -211,7 +225,7 @@ unsafe_evaluate: {
     node_version: ">=8"
 }
 
-side_effects: {
+side_effects_1: {
     options = {
         side_effects: true,
     }
@@ -228,6 +242,30 @@ side_effects: {
     node_version: ">=4"
 }
 
+side_effects_2: {
+    options = {
+        side_effects: true,
+    }
+    input: {
+        var o = {
+            f() {
+                console.log(this === o ? "FAIL" : "PASS");
+            },
+        };
+        (42, o.f)``;
+    }
+    expect: {
+        var o = {
+            f() {
+                console.log(this === o ? "FAIL" : "PASS");
+            },
+        };
+        (0, o.f)``;
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
+
 unsafe_side_effects: {
     options = {
         side_effects: true,
@@ -298,3 +336,33 @@ issue_4630: {
     expect_stdout: "/PASS/"
     node_version: ">=4"
 }
+
+issue_4676: {
+    options = {
+        evaluate: true,
+        reduce_vars: true,
+        templates: true,
+        toplevel: true,
+        unsafe:true,
+        unused: true,
+    }
+    input: {
+        function f(a) {
+            var b = `foo${a = "PASS"}`;
+            for (var c in f && b)
+                b.p;
+            return a;
+        }
+        console.log(f("FAIL"));
+    }
+    expect: {
+        console.log(function f(a) {
+            var b = "fooPASS";
+            for (var c in f, b)
+                b.p;
+            return "PASS";
+        }());
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
