@@ -247,6 +247,30 @@ collapse_vars_4: {
     node_version: ">=4"
 }
 
+collapse_vars_5: {
+    options = {
+        collapse_vars: true,
+    }
+    input: {
+        var a = function* f(b, c) {
+            b = yield c = b;
+            console.log(c);
+        }("PASS");
+        a.next();
+        a.next("FAIL");
+    }
+    expect: {
+        var a = function* f(b, c) {
+            b = yield c = b;
+            console.log(c);
+        }("PASS");
+        a.next();
+        a.next("FAIL");
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
+
 collapse_property_lambda: {
     options = {
         collapse_vars: true,
@@ -388,14 +412,14 @@ functions: {
             function* b() {
                 return !!b;
             }
-            var c = function*(c) {
+            function* c(c) {
                 return c;
-            };
+            }
             if (yield* c(yield* b(yield* a()))) {
-                function* d() {}
-                function* e() {
-                    return typeof e;
-                }
+                var d = function*() {};
+                var e = function* y() {
+                    return typeof y;
+                };
                 var f = function*(f) {
                     return f;
                 };
@@ -446,9 +470,9 @@ functions_use_strict: {
             function* b() {
                 return !!b;
             }
-            var c = function*(c) {
+            function* c(c) {
                 return c;
-            };
+            }
             if (yield* c(yield* b(yield* a()))) {
                 var d = function*() {};
                 var e = function* y() {
@@ -465,6 +489,54 @@ functions_use_strict: {
     node_version: ">=4"
 }
 
+functions_anonymous: {
+    options = {
+        functions: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var yield = function*() {
+            return "PASS";
+        };
+        console.log(yield().next(yield).value);
+    }
+    expect: {
+        function* yield() {
+            return "PASS";
+        }
+        console.log(yield().next(yield).value);
+    }
+    expect_stdout: "PASS"
+    node_version: ">=4"
+}
+
+functions_inner_var: {
+    options = {
+        functions: true,
+        reduce_vars: true,
+        toplevel: true,
+        unused: true,
+    }
+    input: {
+        var yield = function* a() {
+            var a;
+            console.log(a, a);
+        };
+        yield().next(yield);
+    }
+    expect: {
+        function* yield() {
+            var a;
+            console.log(a, a);
+        }
+        yield().next(yield);
+    }
+    expect_stdout: "undefined undefined"
+    node_version: ">=4"
+}
+
 negate_iife: {
     options = {
         negate_iife: true,
@@ -690,7 +762,7 @@ drop_body: {
         })([ console.log("baz") ]);
     }
     expect: {
-        [ [ , 0[0] = console.log("foo") ] ] = [ [ console.log("baz") ] ];
+        [ [ , [].e = console.log("foo") ] ] = [ [ console.log("baz") ] ];
     }
     expect_stdout: [
         "baz",
@@ -950,3 +1022,43 @@ issue_4641_2: {
     ]
     node_version: ">=10"
 }
+
+issue_4769_1: {
+    options = {
+        side_effects: true,
+    }
+    input: {
+        console.log(function*() {
+            (function({} = yield => {}) {})();
+        }().next().done);
+    }
+    expect: {
+        console.log(function*() {
+            (function({} = yield => {}) {})();
+        }().next().done);
+    }
+    expect_stdout: "true"
+    node_version: ">=6"
+}
+
+issue_4769_2: {
+    options = {
+        inline: true,
+    }
+    input: {
+        console.log(function*() {
+            return function({} = yield => {}) {
+                return "PASS";
+            }();
+        }().next().value);
+    }
+    expect: {
+        console.log(function*() {
+            return function({} = yield => {}) {
+                return "PASS";
+            }();
+        }().next().value);
+    }
+    expect_stdout: "PASS"
+    node_version: ">=6"
+}
