@@ -132,6 +132,17 @@ module.exports = function reduce_test(testcase, minify_options, reduce_options)
                 return;
             }
             if (parent instanceof U.AST_VarDef && parent.name === node) return;
+            // preserve exports
+            if (parent instanceof U.AST_ExportDeclaration) return;
+            if (parent instanceof U.AST_ExportDefault) return;
+            if (parent instanceof U.AST_ExportForeign) return;
+            if (parent instanceof U.AST_ExportReferences) return;
+            // preserve sole definition of an export statement
+            if (node instanceof U.AST_VarDef
+                && parent.definitions.length == 1
+                && tt.parent(1) instanceof U.AST_ExportDeclaration) {
+                return;
+            }
             // preserve for (var xxx; ...)
             if (parent instanceof U.AST_For && parent.init === node && node instanceof U.AST_Definitions) return node;
             // preserve for (xxx in/of ...)
@@ -181,7 +192,7 @@ module.exports = function reduce_test(testcase, minify_options, reduce_options)
             }
             else if (node instanceof U.AST_Call) {
                 var expr = [
-                    node.expression,
+                    !(node.expression instanceof U.AST_Super) && node.expression,
                     node.args[0],
                     null,  // intentional
                 ][ ((node.start._permute += step) * steps | 0) % 3 ];
@@ -197,12 +208,10 @@ module.exports = function reduce_test(testcase, minify_options, reduce_options)
                 }
                 if (node.expression instanceof U.AST_Function) {
                     // hoist and return expressions from the IIFE function expression
-                    var body = node.expression.body;
-                    node.expression.body = [];
                     var seq = [];
-                    body.forEach(function(node) {
+                    node.expression.body.forEach(function(node) {
                         var expr = expr instanceof U.AST_Exit ? node.value : node.body;
-                        if (expr instanceof U.AST_Node && !is_statement(expr)) {
+                        if (expr instanceof U.AST_Node && !U.is_statement(expr) && can_hoist(expr)) {
                             // collect expressions from each statements' body
                             seq.push(expr);
                         }
@@ -253,7 +262,7 @@ module.exports = function reduce_test(testcase, minify_options, reduce_options)
                     CHANGED = true;
                     return List.skip;
                   default:
-                    if (!has_exit(node)) {
+                    if (!has_exit(node) && can_hoist(node)) {
                         // hoist function declaration body
                         var body = node.body;
                         node.body = [];
@@ -307,10 +316,11 @@ module.exports = function reduce_test(testcase, minify_options, reduce_options)
                 var expr;
                 switch ((node.start._permute * steps | 0) % 3) {
                   case 0:
-                    if (!(node.init instanceof U.AST_Definitions
-                        && node.init.definitions[0].name instanceof U.AST_Destructured)) {
-                        expr = node.init;
+                    if (node.init instanceof U.AST_Definitions) {
+                        if (node.init instanceof U.AST_Const) break;
+                        if (node.init.definitions[0].name instanceof U.AST_Destructured) break;
                     }
+                    expr = node.init;
                     break;
                   case 1:
                     expr = node.object;
@@ -358,7 +368,7 @@ module.exports = function reduce_test(testcase, minify_options, reduce_options)
             }
             else if (node instanceof U.AST_PropAccess) {
                 var expr = [
-                    node.expression,
+                    !(node.expression instanceof U.AST_Super) && node.expression,
                     node.property instanceof U.AST_Node && !(parent instanceof U.AST_Destructured) && node.property,
                 ][ node.start._permute++ % 2 ];
                 if (expr) {
@@ -370,11 +380,9 @@ module.exports = function reduce_test(testcase, minify_options, reduce_options)
                 if (node.body instanceof U.AST_Call && node.body.expression instanceof U.AST_Function) {
                     // hoist simple statement IIFE function expression body
                     node.start._permute++;
-                    if (!has_exit(node.body.expression)) {
-                        var body = node.body.expression.body;
-                        node.body.expression.body = [];
+                    if (!has_exit(node.body.expression) && can_hoist(node.body.expression)) {
                         CHANGED = true;
-                        return List.splice(body);
+                        return List.splice(node.body.expression.body);
                     }
                 }
             }
@@ -468,7 +476,7 @@ module.exports = function reduce_test(testcase, minify_options, reduce_options)
             }
 
             // replace this node
-            var newNode = is_statement(node) ? new U.AST_EmptyStatement({
+            var newNode = U.is_statement(node) ? new U.AST_EmptyStatement({
                 start: {},
             }) : U.parse(REPLACEMENTS[node.start._permute % REPLACEMENTS.length | 0], {
                 expression: true,
@@ -477,23 +485,27 @@ module.exports = function reduce_test(testcase, minify_options, reduce_options)
             CHANGED = true;
             return newNode;
         }, function(node, in_list) {
-            if (node instanceof U.AST_Sequence) {
+            if (node instanceof U.AST_Definitions) {
+                // remove empty var statement
+                if (node.definitions.length == 0) return in_list ? List.skip : new U.AST_EmptyStatement({
+                    start: {},
+                });
+            } else if (node instanceof U.AST_ObjectMethod) {
+                if (!/Function$/.test(node.value.TYPE)) return new U.AST_ObjectKeyVal({
+                    key: node.key,
+                    value: node.value,
+                    start: {},
+                });
+            } else if (node instanceof U.AST_Sequence) {
                 // expand single-element sequence
                 if (node.expressions.length == 1) return node.expressions[0];
-            }
-            else if (node instanceof U.AST_Try) {
+            } else if (node instanceof U.AST_Try) {
                 // expand orphaned try block
                 if (!node.bcatch && !node.bfinally) return new U.AST_BlockStatement({
                     body: node.body,
                     start: {},
                 });
             }
-            else if (node instanceof U.AST_Definitions) {
-                // remove empty var statement
-                if (node.definitions.length == 0) return in_list ? List.skip : new U.AST_EmptyStatement({
-                    start: {},
-                });
-            }
         });
 
         var diff_error_message;
@@ -662,12 +674,22 @@ function has_loopcontrol(body, loop, label) {
     return found;
 }
 
-function is_timed_out(result) {
-    return sandbox.is_error(result) && /timed out/.test(result.message);
+function can_hoist(body) {
+    var found = false;
+    body.walk(new U.TreeWalker(function(node) {
+        if (found) return true;
+        if (node instanceof U.AST_NewTarget) return found = true;
+        if (node instanceof U.AST_Scope) {
+            if (node === body) return;
+            return true;
+        }
+        if (node instanceof U.AST_Super) return found = true;
+    }));
+    return !found;
 }
 
-function is_statement(node) {
-    return node instanceof U.AST_Statement && !(node instanceof U.AST_LambdaExpression);
+function is_timed_out(result) {
+    return sandbox.is_error(result) && /timed out/.test(result.message);
 }
 
 function merge_sequence(array, node) {
@@ -689,7 +711,7 @@ function to_sequence(expressions) {
 }
 
 function to_statement(node) {
-    return is_statement(node) ? node : new U.AST_SimpleStatement({
+    return U.is_statement(node) ? node : new U.AST_SimpleStatement({
         body: node,
         start: {},
     });
@@ -724,7 +746,7 @@ function run_code(code, toplevel, result_cache, timeout) {
     if (!value) {
         var start = Date.now();
         result_cache[key] = value = {
-            result: sandbox.run_code(code, toplevel, timeout),
+            result: sandbox.run_code(sandbox.patch_module_statements(code), toplevel, timeout),
             elapsed: Date.now() - start,
         };
     }
