@@ -25,7 +25,13 @@ exports.run_code = semver.satisfies(process.version, "0.8") ? function(code, top
     } while (prev !== stdout);
     return stdout;
 } : semver.satisfies(process.version, "<0.12") ? run_code_vm : function(code, toplevel, timeout) {
-    if (/\basync([ \t]+[^\s()[\]{},.&|!~=*%/+-]+|[ \t]*\([\s\S]*?\))[ \t]*=>|\b(async[ \t]+function|setInterval|setTimeout)\b/.test(code)) {
+    if ([
+        /\basync[ \t]*\([\s\S]*?\)[ \t]*=>/,
+        /\b(async[ \t]+function|setImmediate|setInterval|setTimeout)\b/,
+        /\basync([ \t]+|[ \t]*\*[ \t]*)[^\s()[\]{},.&|!~=*%/+-]+(\s*\(|[ \t]*=>)/,
+    ].some(function(pattern) {
+        return pattern.test(code);
+    })) {
         return run_code_exec(code, toplevel, timeout);
     } else {
         return run_code_vm(code, toplevel, timeout);
@@ -43,6 +49,30 @@ exports.same_stdout = semver.satisfies(process.version, "0.12") ? function(expec
 } : function(expected, actual) {
     return typeof expected == typeof actual && strip_func_ids(expected) == strip_func_ids(actual);
 };
+exports.patch_module_statements = function(code) {
+    var count = 0, imports = [];
+    code = code.replace(/\bexport(?:\s*\{[^}]*}\s*?(?:$|\n|;)|\s+default\b(?:\s*(\(|\{|class\s*\{|class\s+(?=extends\b)|(?:async\s+)?function\s*(?:\*\s*)?\())?|\b)/g, function(match, header) {
+        if (!header) return "";
+        if (header.length == 1) return "0, " + header;
+        return header.slice(0, -1) + " _" + ++count + header.slice(-1);
+    }).replace(/\bimport\.meta\b/g, function() {
+        return '({ url: "https://example.com/path/index.html" })';
+    }).replace(/\bimport\b(?:\s*([^('"]+)\bfrom\b)?\s*(['"]).*?\2(?:$|\n|;)/g, function(match, symbols) {
+        if (symbols) {
+            if (!/^[{*]/.test(symbols)) symbols = "default:" + symbols;
+            symbols = symbols.replace(/[{}]/g, "").trim().replace(/\s*,\s*/g, ",");
+            symbols = symbols.replace(/\*/, '"*"').replace(/\bas\s+(?!$|,|as\s)/g, ":");
+            imports.push([
+                "const {",
+                symbols,
+                "} = new Proxy(Object.create(null), { get(_, value) { return { value }; } });",
+            ].join(""));
+        }
+        return "";
+    });
+    imports.push("");
+    return imports.join("\n") + code;
+};
 
 function is_error(result) {
     return result && typeof result.name == "string" && typeof result.message == "string";
@@ -147,12 +177,14 @@ function setup(global, builtins, setup_log, setup_tty) {
     [
         // for Node.js v0.12
         "Buffer",
+        "clearImmediate",
         "clearInterval",
         "clearTimeout",
         // for Node.js v0.12
         "DTRACE_NET_STREAM_END",
         // for Node.js v8
         "process",
+        "setImmediate",
         "setInterval",
         "setTimeout",
     ].forEach(function(name) {
@@ -170,9 +202,13 @@ function setup(global, builtins, setup_log, setup_tty) {
     });
     Object.defineProperties(global, props);
     // for Node.js v8+
-    global.toString = function() {
-        return "[object global]";
-    };
+    if (global.toString !== Object.prototype.toString) {
+        global.__proto__ = Object.defineProperty(Object.create(global.__proto__), "toString", {
+            value: function() {
+                return "[object global]";
+            },
+        });
+    }
 
     function self() {
         return this;
@@ -186,7 +222,7 @@ function setup(global, builtins, setup_log, setup_tty) {
             if (arg === global) return "[object global]";
             if (/Error$/.test(arg.name)) return arg.toString();
             if (typeof arg.then == "function") return "[object Promise]";
-            arg.constructor.toString();
+            if (arg.constructor) arg.constructor.toString();
             var index = cache.original.indexOf(arg);
             if (index >= 0) return cache.replaced[index];
             if (--cache.level < 0) return "[object Object]";
